agentle.mcp.resources.text\_resources.textfyable
================================================

.. automodule:: agentle.mcp.resources.text_resources.textfyable

   
   .. rubric:: Classes

   .. autosummary::
   
      Textfyable
   